%define libname %mklibname %{name}

Summary:	Advanced Linux Sound Architecture (ALSA) plugins
Name:		alsa-plugins
Version:	1.1.1
Release:	%mkrel 4
Source0:	ftp://ftp.alsa-project.org/pub/plugins/%{name}-%{version}.tar.bz2
Source1:	jack.conf
Source2:	samplerate.conf
Source3:	upmix.conf
Source4:	vdownmix.conf
Source5:	a52.conf
# All packages are LGPLv2+ with the exception of samplerate which is GPLv2+
License:	GPLv2+ and LGPLv2+
Group:		Sound/Utilities
URL:		http://www.alsa-project.org

BuildRequires:	kernel-headers >= 2.4.0
BuildRequires:	pkgconfig(alsa) >= %{version}
BuildRequires:	pkgconfig(libpulse) >= 0.8
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(speex)

%description
Advanced Linux Sound Architecture (ALSA) utilities. Modularized architecture
with support for a large range of ISA and PCI cards. Fully compatible with
OSS/Lite (kernel sound drivers), but contains many enhanced features.

This is the plugins package, which allows you to manipulate ALSA settings.

%package -n	%{libname}
Summary:	Advanced Linux Sound Architecture (ALSA) plugins
Group:		System/Libraries
Provides:	%{name} = %{version}-%{release}
Obsoletes:	%{name} < %{version}-%{release}
Requires:	libalsa >= %{version}
Requires:	%name-config = %version

%description -n	%{libname}
Advanced Linux Sound Architecture (ALSA) utilities. Modularized architecture
with support for a large range of ISA and PCI cards. Fully compatible with
OSS/Lite (kernel sound drivers), but contains many enhanced features.

This is the plugins package, which allows you to manipulate ALSA settings.

%package	doc
Summary:	Advanced Linux Sound Architecture (ALSA) plugins
Group:		Documentation
BuildArch:	noarch

%description	doc
Documentation for %{name}

# (tv) needed for biarch:
%package config
Summary:	Alsa plugins configuration
Group:		System/Configuration
BuildArch:	noarch
License:	LGPLv2+
Conflicts: 	lib64alsa-plugins <= 1.1.1-1.mga6
Conflicts: 	libalsa-plugins <= 1.1.1-1.mga6

%description config
This package contains configuration files for ALSA plugins.

# (tv) needed for biarch:
%package	pulse-config
Summary:	Alsa to PulseAudio backend configuration
Group:		System/Configuration
BuildArch:	noarch
License:	LGPLv2+
# (eatdirt) Otherwise config file alone
Requires:	alsa-plugins-pulseaudio
# (cg) For upgrading from old configuration system
Requires(post):	libalsa-data >= 1.0.20-2
Requires(post):	update-alternatives

%description	pulse-config
This package contains configuration files for the pulse ALSA plugin.

%post pulse-config
# (cg) Check to see if the user has disabled pulse in the old style setup.
if [ -f %{_sysconfdir}/alsa/pulse-default.conf ]; then
  if grep "^#DRAKSOUND- " %{_sysconfdir}/alsa/pulse-default.conf 2>/dev/null >/dev/null; then
    update-alternatives --set soundprofile /etc/sound/profiles/alsa
  fi
fi

%package -n	%{libname}-pulseaudio
Summary:	Alsa to PulseAudio backend
Group:		System/Libraries 
License:	LGPLv2+
Provides:	%{name}-pulseaudio = %{version}-%{release}
Requires:	%{name}-pulse-config
%ifarch x86_64
# (cg) Suggest the 32 bit plugin on 64 bits to ensure compatibility
#      with (typically closed source) 32 bit apps.
Recommends:	lib%{name}-pulseaudio
%endif

%description -n	%{libname}-pulseaudio
This plugin allows any program that uses the ALSA API to access a PulseAudio
sound daemon. In other words, native ALSA applications can play and record
sound across a network. There are two plugins in the suite, one for PCM and
one for mixer control.

%package -n	%{libname}-jack
Summary:	Jack PCM output plugin for ALSA
Group:		System/Libraries 
License:	LGPLv2+
Provides:	%{name}-jack = %{version}-%{release}

%description -n	%{libname}-jack
This plugin converts the ALSA API over JACK (Jack Audio Connection
Kit, http://jackit.sf.net) API.  ALSA native applications can work
transparently together with jackd for both playback and capture.

    ALSA apps (playback) -> ALSA-lib -> JACK plugin -> JACK daemon
    ALSA apps (capture) <- ALSA-lib <- JACK plugin <- JACK daemon

This plugin provides the PCM type "jack"

%package -n	%{libname}-a52
Summary:	A52/AC3 output plugin for ALSA
Group:		System/Libraries 
License:	LGPLv2+
Provides:	%{name}-a52 = %{version}-%{release}
Conflicts:	%{libname} <= 1.0.25-1

%description -n	%{libname}-a52
This plugin supports Digital 5.1 AC3 emulation over S/PDIF (IEC958).

%prep
%setup -q 
%autopatch -p1

%build
autoreconf -fi
%configure2_5x
%make

%install
%makeinstall_std mkdir_p="mkdir -p"

find %{buildroot} -name '*.la' | xargs rm

install -d %{buildroot}%{_sysconfdir}/alsa

install -d %{buildroot}%{_datadir}/alsa/pcm
install -m 644 %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4} %{buildroot}%{_datadir}/alsa/pcm
install -m 644 %{SOURCE5} %{buildroot}%{_datadir}/alsa/alsa.conf.d

# (cg) Include a configuration for when pulse is active
install -d  %{buildroot}%{_sysconfdir}/sound/profiles/pulse

# (cg) Use the "pulseaudio by default" config for the pulse sound profile.
ln -s %{_datadir}/alsa/alsa.conf.d/99-pulseaudio-default.conf.example %{buildroot}%{_sysconfdir}/sound/profiles/pulse/alsa-default.conf

%files doc
%doc COPYING* doc/R* doc/*.txt

%files -n %{libname}
%exclude %{_libdir}/alsa-lib/*_pulse.so
%exclude %{_libdir}/alsa-lib/*_jack.so
%exclude %{_libdir}/alsa-lib/*_a52.so
%_libdir/alsa-lib/*

%files config
%{_datadir}/alsa/pcm/samplerate.conf
%{_datadir}/alsa/pcm/upmix.conf
%{_datadir}/alsa/pcm/vdownmix.conf

%files pulse-config
%{_datadir}/alsa/alsa.conf.d/50-pulseaudio.conf
%{_datadir}/alsa/alsa.conf.d/99-pulseaudio-default.conf.example
%{_sysconfdir}/sound/profiles/pulse/alsa-default.conf

%files -n %{libname}-pulseaudio
%doc doc/README-pulse
%{_libdir}/alsa-lib/libasound_module_pcm_pulse.so
%{_libdir}/alsa-lib/libasound_module_ctl_pulse.so
%{_libdir}/alsa-lib/libasound_module_conf_pulse.so

%files -n %{libname}-jack
%doc doc/README-jack
%{_datadir}/alsa/pcm/jack.conf
%{_libdir}/alsa-lib/libasound_module_pcm_jack.so

%files -n %{libname}-a52
%{_datadir}/alsa/alsa.conf.d/a52.conf
%{_libdir}/alsa-lib/libasound_module_pcm_a52.so



%changelog
* Tue May 02 2017 akien <akien> 1.1.1-4.mga6
+ Revision: 1098348
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 1.1.1-3.mga6
+ Revision: 1089833
- Rebuild for ffmpeg 3.2.4

* Sun Jan 29 2017 tv <tv> 1.1.1-2.mga6
+ Revision: 1083925
- split config files thus fixing upgrade of biarch mga5
- rebuild for new libavcodec

* Fri Apr 01 2016 tv <tv> 1.1.1-1.mga6
+ Revision: 997366
- new release

* Sat Feb 13 2016 umeabot <umeabot> 1.1.0-2.mga6
+ Revision: 959485
- Mageia 6 Mass Rebuild

  + tv <tv>
    - switch to pkgconfig() BRs

* Mon Nov 09 2015 tv <tv> 1.1.0-1.mga6
+ Revision: 900065
- new release

* Tue Jun 23 2015 tv <tv> 1.0.29-1.mga6
+ Revision: 840245
- new release

* Fri Nov 14 2014 fwang <fwang> 1.0.28-6.mga5
+ Revision: 796997
- rebuild for new ffmpeg

* Wed Oct 15 2014 umeabot <umeabot> 1.0.28-5.mga5
+ Revision: 743289
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.0.28-4.mga5
+ Revision: 725938
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.0.28-3.mga5
+ Revision: 686489
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.0.28-2.mga5
+ Revision: 677740
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

* Wed Jun 18 2014 tv <tv> 1.0.28-1.mga5
+ Revision: 637902
- drop merged patches
- new release

* Sat Oct 19 2013 umeabot <umeabot> 1.0.27-3.mga4
+ Revision: 529959
- Mageia 4 Mass Rebuild

* Mon Jul 15 2013 fwang <fwang> 1.0.27-2.mga4
+ Revision: 454502
- correct condition
- check new function
- rebuild for new ffmpeg

* Fri May 24 2013 tv <tv> 1.0.27-1.mga4
+ Revision: 426567
- drop merged patches
- new release

* Wed Jan 23 2013 fwang <fwang> 1.0.26-4.mga3
+ Revision: 391393
- update rpm group

* Fri Jan 11 2013 umeabot <umeabot> 1.0.26-3.mga3
+ Revision: 345517
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 21 2012 barjac <barjac> 1.0.26-2.mga3
+ Revision: 320104
- Changed group(s) in line with new policy
- spec clean mainly indentation and tabs

* Wed Sep 12 2012 fwang <fwang> 1.0.26-1.mga3
+ Revision: 292479
- new version 1.0.26

* Wed May 30 2012 fwang <fwang> 1.0.25-4.mga3
+ Revision: 250182
- fix build with latest ffmpeg

  + ovitters <ovitters>
    - rebuild due to new ffmpeg

* Sun Apr 15 2012 colin <colin> 1.0.25-3.mga2
+ Revision: 230910
- Slightly improved a52 config file.

* Sun Apr 15 2012 colin <colin> 1.0.25-2.mga2
+ Revision: 230887
- Split a52 plugin into subpackage and provide default config.

* Wed Jan 25 2012 colin <colin> 1.0.25-1.mga2
+ Revision: 201523
- New version: 1.0.25

* Mon Nov 28 2011 eatdirt <eatdirt> 1.0.24-5.mga2
+ Revision: 173850
- pulse-config now requires alsa-plugins-pulseaudio (bug #2966)

* Thu Sep 22 2011 fwang <fwang> 1.0.24-4.mga2
+ Revision: 146757
- update missing versioned req
- drop .la files

* Sat Sep 17 2011 colin <colin> 1.0.24-3.mga2
+ Revision: 144508
- Use upstream-submitted patch for pulseaudio config
- Tidy up some sources (pcm-oss was unused)
- Make alsa-plugins-pulse-config noarch

  + ze <ze>
    - set documents package as noarch

* Fri Jun 24 2011 fwang <fwang> 1.0.24-2.mga2
+ Revision: 113071
- rebuild for new ffmpeg

* Tue Mar 08 2011 ahmad <ahmad> 1.0.24-1.mga1
+ Revision: 66354
- update to 1.0.24

* Sun Jan 09 2011 ahmad <ahmad> 1.0.23-3.mga1
+ Revision: 3180
- clean spec and drop some old conflicts tags
- imported package alsa-plugins

